@@ -12,43 +12,91 @@ import math
 from scipy.stats import hypergeom
 import logging
 import numpy as np
+try:
+    if tkinter_ok:
+        try:
+            from tkinter import *
+            from tkinter import ttk
+        except ImportError:
+            tkinter_ok = False
+except NameError:
+    tkinter_ok = False
 
 EPSILON = np.finfo(np.float32).eps
 logger = logging.getLogger(__name__)
 
 # TODO (pcotte) typing
 
+if tkinter_ok:
+    class StatusBox:
+        def __init__(self):
+            self.root = Tk()
+            self.root.title('irMF status - Python kernel')
+            self.root.minsize(width=230, height=60)
+            self.frame = Frame(self.root, borderwidth=6)
+            self.frame.pack()
+            self.var = StringVar()
+            self.status = Label(self.frame, textvariable=self.var, width=60, height=1)
+            self.status.pack(fill=NONE, padx=6, pady=6)
+            self.pbar = ttk.Progressbar(self.frame, orient=HORIZONTAL, max=100, mode='determinate')
+            self.pbar.pack(fill=NONE, padx=6, pady=6)
+            Button(self.frame, text='Cancel', command=self.close_dialog).pack(fill=NONE, padx=6, pady=6)
+            self.cancel_pressed = False
+            self.n_steps = 0
 
-class StatusBoxTqdm:
-    def __init__(self, verbose=0):
-        self.log_iter = verbose
-        if self.log_iter == 0:
-            self.pbar = tqdm(total=100)
+        def close_dialog(self):
+            self.cancel_pressed = True
 
-        self.cancel_pressed = False
+        def update_bar(self, delay=1, step=1):
+            self.n_steps += step
+            self.pbar.step(step)
+            self.pbar.after(delay, lambda: self.root.quit())
+            self.root.mainloop()
 
-    def update_bar(self, step=1):
-        if self.log_iter == 0:
-            self.pbar.update(n=step)
+        def init_bar(self, delay=1):
+            self.update_bar(delay=1, step=100 - self.n_steps)
+            self.n_steps = 0
 
-    def init_bar(self):
-        if self.log_iter == 0:
-            self.pbar.n = 0
+        def update_status(self, delay=1, status=''):
+            self.var.set(status)
+            self.status.after(delay, lambda: self.root.quit())
+            self.root.mainloop()
 
-    def update_status(self, status=""):
-        if self.log_iter == 0:
-            self.pbar.set_description(status, refresh=False)
-            self.pbar.refresh()
+        def close(self):
+            self.root.destroy()
 
-    def close(self):
-        if self.log_iter == 0:
-            self.pbar.clear()
-            self.pbar.close()
+        def myPrint(self, status=''):
+            print(status)
+else:
+    class StatusBox:
+        def __init__(self, verbose=0):
+            self.log_iter = verbose
+            if self.log_iter == 0:
+                self.pbar = tqdm(total=100)
 
-    def my_print(self, status=""):
-        if self.log_iter == 1:
-            logger.info(status)
+            self.cancel_pressed = False
 
+        def update_bar(self, step=1):
+            if self.log_iter == 0:
+                self.pbar.update(n=step)
+
+        def init_bar(self):
+            if self.log_iter == 0:
+                self.pbar.n = 0
+
+        def update_status(self, status=""):
+            if self.log_iter == 0:
+                self.pbar.set_description(status, refresh=False)
+                self.pbar.refresh()
+
+        def close(self):
+            if self.log_iter == 0:
+                self.pbar.clear()
+                self.pbar.close()
+
+        def my_print(self, status=""):
+            if self.log_iter == 1:
+                logger.info(status)
 
 def nmf_det(mt, mw, nmf_exact_det):
     """Volume occupied by Left and Right factoring vectors
